From: Tomi Valkeinen <tomi.valkeinen+renesas@ideasonboard.com>
To: "Niklas Söderlund" <niklas.soderlund@ragnatech.se>,
"Mauro Carvalho Chehab" <mchehab@kernel.org>,
"Sakari Ailus" <sakari.ailus@linux.intel.com>
Cc: linux-media@vger.kernel.org, linux-renesas-soc@vger.kernel.org,
linux-kernel@vger.kernel.org,
"Niklas Söderlund" <niklas.soderlund+renesas@ragnatech.se>,
"Mauro Carvalho Chehab" <mchehab+huawei@kernel.org>,
"Laurent Pinchart" <laurent.pinchart@ideasonboard.com>,
"Jacopo Mondi" <jacopo.mondi@ideasonboard.com>,
"Tomi Valkeinen" <tomi.valkeinen+renesas@ideasonboard.com>
Subject: [PATCH v6 05/11] media: rcar-csi2: Switch to Streams API
Date: Wed, 17 Jun 2026 14:54:58 +0300 [thread overview]
Message-ID: <20260617-rcar-streams-v6-5-1260eb72dff7@ideasonboard.com> (raw)
In-Reply-To: <20260617-rcar-streams-v6-0-1260eb72dff7@ideasonboard.com>
Switch to Streams API with a single hardcoded route.
For single-stream use case there should be no change in behavior.
Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com>
Signed-off-by: Tomi Valkeinen <tomi.valkeinen+renesas@ideasonboard.com>
---
drivers/media/platform/renesas/rcar-csi2.c | 64 +++++++++++++++++++++++-------
1 file changed, 50 insertions(+), 14 deletions(-)
diff --git a/drivers/media/platform/renesas/rcar-csi2.c b/drivers/media/platform/renesas/rcar-csi2.c
index f5d8b06dff51..91f713e1f8c2 100644
--- a/drivers/media/platform/renesas/rcar-csi2.c
+++ b/drivers/media/platform/renesas/rcar-csi2.c
@@ -1023,17 +1023,24 @@ static int rcsi2_calc_mbps(struct rcar_csi2 *priv,
*/
freq = v4l2_get_link_freq(remote_pad, 0, 0);
if (freq < 0) {
+ const struct v4l2_subdev_route *route;
const struct rcar_csi2_format *format;
const struct v4l2_mbus_framefmt *fmt;
unsigned int lanes;
unsigned int bpp;
int ret;
+ if (state->routing.num_routes != 1)
+ return -EINVAL;
+
ret = rcsi2_get_active_lanes(priv, &lanes);
if (ret)
return ret;
- fmt = v4l2_subdev_state_get_format(state, RCAR_CSI2_SINK);
+ route = &state->routing.routes[0];
+
+ fmt = v4l2_subdev_state_get_format(state, route->sink_pad,
+ route->sink_stream);
if (!fmt)
return -EINVAL;
@@ -1062,6 +1069,7 @@ static int rcsi2_calc_mbps(struct rcar_csi2 *priv,
static int rcsi2_start_receiver_gen3(struct rcar_csi2 *priv,
struct v4l2_subdev_state *state)
{
+ const struct v4l2_subdev_route *route;
const struct rcar_csi2_format *format;
u32 phycnt, vcdt = 0, vcdt2 = 0, fld = 0;
const struct v4l2_mbus_framefmt *fmt;
@@ -1070,7 +1078,16 @@ static int rcsi2_start_receiver_gen3(struct rcar_csi2 *priv,
int mbps, ret;
/* Use the format on the sink pad to compute the receiver config. */
- fmt = v4l2_subdev_state_get_format(state, RCAR_CSI2_SINK);
+
+ if (state->routing.num_routes != 1)
+ return -EINVAL;
+
+ route = &state->routing.routes[0];
+
+ fmt = v4l2_subdev_state_get_format(state, route->sink_pad,
+ route->sink_stream);
+ if (!fmt)
+ return -EINVAL;
dev_dbg(priv->dev, "Input size (%ux%u%c)\n",
fmt->width, fmt->height,
@@ -1892,8 +1909,7 @@ static int rcsi2_set_pad_format(struct v4l2_subdev *sd,
struct v4l2_subdev_state *state,
struct v4l2_subdev_format *format)
{
- struct rcar_csi2 *priv = sd_to_csi2(sd);
- unsigned int num_pads = rcsi2_num_pads(priv);
+ struct v4l2_mbus_framefmt *fmt;
if (format->pad > RCAR_CSI2_SINK)
return v4l2_subdev_get_fmt(sd, state, format);
@@ -1901,11 +1917,20 @@ static int rcsi2_set_pad_format(struct v4l2_subdev *sd,
if (!rcsi2_code_to_fmt(format->format.code))
format->format.code = rcar_csi2_formats[0].code;
- *v4l2_subdev_state_get_format(state, format->pad) = format->format;
+ /* Set sink format. */
+ fmt = v4l2_subdev_state_get_format(state, format->pad, format->stream);
+ if (!fmt)
+ return -EINVAL;
+
+ *fmt = format->format;
+
+ /* Propagate the format to the source pad. */
+ fmt = v4l2_subdev_state_get_opposite_stream_format(state, format->pad,
+ format->stream);
+ if (!fmt)
+ return -EINVAL;
- /* Propagate the format to the source pads. */
- for (unsigned int i = RCAR_CSI2_SOURCE_VC0; i < num_pads; i++)
- *v4l2_subdev_state_get_format(state, i) = format->format;
+ *fmt = format->format;
return 0;
}
@@ -1925,8 +1950,15 @@ static const struct v4l2_subdev_ops rcar_csi2_subdev_ops = {
static int rcsi2_init_state(struct v4l2_subdev *sd,
struct v4l2_subdev_state *state)
{
- struct rcar_csi2 *priv = sd_to_csi2(sd);
- unsigned int num_pads = rcsi2_num_pads(priv);
+ static struct v4l2_subdev_route routes[] = {
+ {
+ .sink_pad = RCAR_CSI2_SINK,
+ .sink_stream = 0,
+ .source_pad = RCAR_CSI2_SOURCE_VC0,
+ .source_stream = 0,
+ .flags = V4L2_SUBDEV_ROUTE_FL_ACTIVE,
+ },
+ };
static const struct v4l2_mbus_framefmt rcar_csi2_default_fmt = {
.width = 1920,
@@ -1939,10 +1971,13 @@ static int rcsi2_init_state(struct v4l2_subdev *sd,
.xfer_func = V4L2_XFER_FUNC_DEFAULT,
};
- for (unsigned int i = RCAR_CSI2_SINK; i < num_pads; i++)
- *v4l2_subdev_state_get_format(state, i) = rcar_csi2_default_fmt;
+ static const struct v4l2_subdev_krouting routing = {
+ .num_routes = ARRAY_SIZE(routes),
+ .routes = routes,
+ };
- return 0;
+ return v4l2_subdev_set_routing_with_fmt(sd, state, &routing,
+ &rcar_csi2_default_fmt);
}
static const struct v4l2_subdev_internal_ops rcar_csi2_internal_ops = {
@@ -2629,7 +2664,8 @@ static int rcsi2_probe(struct platform_device *pdev)
v4l2_set_subdevdata(&priv->subdev, &pdev->dev);
snprintf(priv->subdev.name, sizeof(priv->subdev.name), "%s %s",
KBUILD_MODNAME, dev_name(&pdev->dev));
- priv->subdev.flags = V4L2_SUBDEV_FL_HAS_DEVNODE;
+ priv->subdev.flags = V4L2_SUBDEV_FL_HAS_DEVNODE |
+ V4L2_SUBDEV_FL_STREAMS;
priv->subdev.entity.function = MEDIA_ENT_F_PROC_VIDEO_PIXEL_FORMATTER;
priv->subdev.entity.ops = &rcar_csi2_entity_ops;
--
2.43.0
next prev parent reply other threads:[~2026-06-17 11:56 UTC|newest]
Thread overview: 24+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-06-17 11:54 [PATCH v6 00/11] media: rcar: Streams support Tomi Valkeinen
2026-06-17 11:54 ` [PATCH v6 01/11] media: rcar-vin: Fix comment related to stride handling Tomi Valkeinen
2026-09-07 10:37 ` Niklas Söderlund
2026-06-17 11:54 ` [PATCH v6 02/11] media: rcar-vin: Link VINs on Gen3 to a single channel on each CSI-2 Tomi Valkeinen
2026-06-17 11:54 ` [PATCH v6 03/11] media: rcar-isp: Move {enable|disable}_streams() calls Tomi Valkeinen
2026-09-07 11:30 ` Niklas Söderlund
2026-06-17 11:54 ` [PATCH v6 04/11] media: rcar-csi2: " Tomi Valkeinen
2026-09-07 11:33 ` Niklas Söderlund
2026-06-17 11:54 ` Tomi Valkeinen [this message]
2026-09-07 12:39 ` [PATCH v6 05/11] media: rcar-csi2: Switch to Streams API Niklas Söderlund
2026-06-17 11:54 ` [PATCH v6 06/11] media: rcar-isp: " Tomi Valkeinen
2026-09-07 13:29 ` Niklas Söderlund
2026-06-17 11:55 ` [PATCH v6 07/11] media: rcar-csi2: Add .get_frame_desc op Tomi Valkeinen
2026-09-07 12:45 ` Niklas Söderlund
2026-06-17 11:55 ` [PATCH v6 08/11] media: rcar-isp: Call get_frame_desc to find out VC & DT Tomi Valkeinen
2026-09-07 14:45 ` Niklas Söderlund
2026-06-17 11:55 ` [PATCH v6 09/11] media: rcar-csi2: Call get_frame_desc to find out VC & DT (Gen3) Tomi Valkeinen
2026-09-07 12:46 ` Niklas Söderlund
2026-06-17 11:55 ` [PATCH v6 10/11] media: rcar-csi2: Add full streams support Tomi Valkeinen
2026-09-07 12:48 ` Niklas Söderlund
2026-06-17 11:55 ` [PATCH v6 11/11] media: rcar-isp: " Tomi Valkeinen
2026-09-07 19:21 ` Niklas Söderlund
2026-09-07 19:25 ` [PATCH v6 00/11] media: rcar: Streams support Niklas Söderlund
2026-09-08 6:28 ` Tomi Valkeinen
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260617-rcar-streams-v6-5-1260eb72dff7@ideasonboard.com \
--to=tomi.valkeinen+renesas@ideasonboard.com \
--cc=jacopo.mondi@ideasonboard.com \
--cc=laurent.pinchart@ideasonboard.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-media@vger.kernel.org \
--cc=linux-renesas-soc@vger.kernel.org \
--cc=mchehab+huawei@kernel.org \
--cc=mchehab@kernel.org \
--cc=niklas.soderlund+renesas@ragnatech.se \
--cc=niklas.soderlund@ragnatech.se \
--cc=sakari.ailus@linux.intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox